# Settings for LinearRegressionTraining
MAX_ITER = 10000
ALPHA = 1e-25

# MLdriver configs
DEFAULT_ITER_INCREASE_STEPS_LOG = 0
DEFAULT_ITER_INCREASE_STEPS = 2**DEFAULT_ITER_INCREASE_STEPS_LOG
DEFAULT_RANGE_ = range(1, 2)

# LinearRegressionTraining DEFAULT settings
ALPHA_LinearRegressionTraining = 0.1e-20
MAX_ITER_LinearRegressionTraining = 10000

# Output prefix
OUTPUT_PREFIX = "result_"
OUTPUT_PREFIX_0 = "result_0"

# AutoDriver
AUTO_DRIVER_DEFAULT_OUTPUT_NAME = "result.png"
