rafcomputingapi_mock_submit = {
    "program":
    "Bubble sort",
    "name":
    "results_20200415112451",
    "data": [
        {
            "input": 65536,
            "output": 17.035170
        },
        {
            "input": 1048576,
            "output": 4383.926270
        },
    ],
    "sys": {
        "Architecture": "x86_64",
        "CPU op-mode(s)": "32-bit, 64-bit",
        "Byte Order": "Little Endian",
        "CPU(s)": "4",
        "On-line CPU(s) list": "0-3",
        "Thread(s) per core": "1",
        "Core(s) per socket": "4",
        "Socket(s)": "1",
        "NUMA node(s)": "1",
        "Vendor ID": "GenuineIntel",
        "CPU family": "6",
        "Model": "58",
        "Stepping": "9",
        "CPU MHz": "3201.000",
        "BogoMIPS": "6385.77",
        "Virtualization": "VT-x",
        "L1d cache": "32K",
        "L1i cache": "32K",
        "L2 cache": "256K",
        "L3 cache": "6144K",
        "NUMA node0 CPU(s)": "0-3",
    },
}
